<?php

namespace Ems\Logic\ProcessamentoSolicitacao;

use Ems\Util\Utils;
use Util\{ DateUtil, NovoCodigo, Repositories };

class ProcessamentoSolicitacaoPessoal extends ProcessamentoSolicitacao {
    
    public function efetivar() {
        $itens      = $this->getItensAssociativeArray();
        $extraRow   = $this->getExtraRow();
        
        $nrorg      = Utils::getParamters()->getNrorg();
        $nrvinculom = $this->getSolicitacao()->getNrvinculom();
        $cdstatus   = $extraRow['CDSTATUS'] ?? null;
        
        $dataset = $itens;
        
        $dataset["update"] = false;
        $dataset["CDSTATUS"] = $cdstatus;
        $dataset["NRESTRUTURAM"] = $dataset["NRESTRUTGEREN"];
        
        $this->adicionarUpdateProcesso($dataset);
    }
    
    public function rejeitar() {}
    
    public function adicionarUpdateProcesso($dataset) {
        $nrorg = Utils::getParamters()->getNrorg();
        $cdoperador = Utils::getParamters()->getCdoperador();
        $update = filter_var($dataset["update"], FILTER_VALIDATE_BOOLEAN);

        $dataset["IDPUBLICAVAGA"] = ($dataset["IDPUBLICAVAGA"] == 'Y' || $dataset["IDPUBLICAVAGA"] == 'S') ? 'S' : 'N';

        $idpublicavaga         = (isset($dataset["IDPUBLICAVAGA"]))         ? $dataset["IDPUBLICAVAGA"]         : null;
        $nrocupacaodesejada    = (isset($dataset["NROCUPACAOM"]))           ? $dataset["NROCUPACAOM"]           : null;
        $nrescalatrabm         = (isset($dataset["NRESCALATRABM"]))         ? $dataset["NRESCALATRABM"]         : null;
        $nrestrutgeren         = (isset($dataset["NRESTRUTURAM"]))          ? $dataset["NRESTRUTURAM"]          : null;
        $nrvagas               = (isset($dataset["NRVAGAS"]))               ? $dataset["NRVAGAS"]               : null;
        $idstatus              = (isset($dataset["CDSTATUS"]))              ? $dataset["CDSTATUS"]              : null;
        $dtlimsolicita         = (isset($dataset["DTLIMSOLICITA"]))         ? $dataset["DTLIMSOLICITA"]         : null;
        $dtsolicita            = (isset($dataset["DTSOLICITA"]))            ? $dataset["DTSOLICITA"]            : null;
        $nmprocesso            = (isset($dataset["NMPROCESSO"]))            ? $dataset["NMPROCESSO"]            : null;
        $vrsalario             = (isset($dataset["VRSALARIO"]))             ? $dataset["VRSALARIO"]             : null;
        $nrtemplate            = (isset($dataset["NRTEMPLATE"]))            ? $dataset["NRTEMPLATE"]            : null;
        $nrtipoprocesso        = (isset($dataset["NRTIPOPROCESSO"]))        ? $dataset["NRTIPOPROCESSO"]        : null;
        $nrparcnegociosolicita = (isset($dataset["NRPARCNEGOCIOSOLICITA"])) ? $dataset["NRPARCNEGOCIOSOLICITA"] : null;
        $nrparcnegocioresp     = (isset($dataset["NRPARCNEGOCIORESP"]))     ? $dataset["NRPARCNEGOCIORESP"]     : null;
        $dsmotivo              = (isset($dataset["DSMOTIVO"]))              ? $dataset["DSMOTIVO"]              : null;
        $dsdescricao           = (isset($dataset["DSDESCRICAO"]))           ? $dataset["DSDESCRICAO"]           : null;
        $dslocalidade          = (isset($dataset["LOCALIDADE"]))            ? $dataset["LOCALIDADE"]            : null;
        $dtsuspensao           = (isset($dataset["DTSUSPENSAO"]))           ? $dataset["DTSUSPENSAO"]           : null;
        $dtcancelamento        = (isset($dataset["DTCANCELAMENTO"]))        ? $dataset["DTCANCELAMENTO"]        : null;
        $dtretorno             = (isset($dataset["DTRETORNO"]))             ? $dataset["DTRETORNO"]             : null;
        $nrprioridade          = (isset($dataset["NRPRIORIDADE"]))          ? $dataset["NRPRIORIDADE"]          : null;
        $dtconclusao           = (isset($dataset["DTCONCLUSAO"]))           ? $dataset["DTCONCLUSAO"]           : null;


        Utils::getEntityManager()->beginTransaction();


        $dtlimsolicita = DateUtil::getDataDeString($dtlimsolicita, DateUtil::FORMATO_BRASILEIRO, true);
        $dtsolicita = DateUtil::getDataDeString($dtsolicita, DateUtil::FORMATO_BRASILEIRO, true);
        if (!empty($dtsuspensao)){
          $dtsuspensao = DateUtil::getDataDeString($dtsuspensao, DateUtil::FORMATO_BRASILEIRO, true);
        } else {
          $dtsuspensao = null;
        }
        if (!empty($dtcancelamento)){
          $dtcancelamento = DateUtil::getDataDeString($dtcancelamento, DateUtil::FORMATO_BRASILEIRO, true);
        } else {
          $dtcancelamento = null;
        }
        if (!empty($dtretorno)){
          $dtretorno = DateUtil::getDataDeString($dtretorno, DateUtil::FORMATO_BRASILEIRO, true);
        } else {
          $dtretorno = null;
        }
        if(!empty($dtconclusao)){
          $dtconclusao = DateUtil::getDataDeString($dtconclusao, DateUtil::FORMATO_BRASILEIRO, true);
        } else {
          $dtconclusao = null;
        }
          
        if ($update) {
            $nrprocesso = $dataset["NRPROCESSO"];

            /** @var $processo \Folha\Entities\DesProcesso */
            $processo = Utils::getEntityManager()->getRepository('\Folha\Entities\DesProcesso')
                ->findOneBy(array('nrprocesso' => $nrprocesso,
                                       'nrorg' => $nrorg));


        } else {
            $nrprocesso = NovoCodigo::geraCodigo($nrorg, 'DES_PROCESSO', 1, 22, true);

            /** @var $processo \Folha\Entities\DesProcesso */
            $nrorginclusao = (isset($nrorg)) ? $nrorg : null;
            $dtinclusao = (isset($nrorg)) ? $nrorg : null;
            $nrorginclusao = (isset($nrorg)) ? $nrorg : null;
            $processo = new \Folha\Entities\DesProcesso();
            $processo->setNrprocesso($nrprocesso);
            $processo->setNrorg($nrorg);
            $processo->setDtinclusao(DateUtil::getDataAtual());
            $processo->setCdoperinclusao($cdoperador);
            $processo->setNrorginclusao($nrorg);
        }
        $processo->setIdpublicavaga($idpublicavaga);
        $processo->setNrocupacaodesejada($nrocupacaodesejada);
        $processo->setNrescalatrabm($nrescalatrabm);
        $processo->setNrestrutgeren($nrestrutgeren);
        $processo->setNrvagas($nrvagas);
        $processo->setidstatus($idstatus);
        $processo->setDtlimsolicita($dtlimsolicita);
        $processo->setDtsolicita($dtsolicita);
        $processo->setNmprocesso($nmprocesso);
        $processo->setVrsalario($vrsalario);
        $processo->setNrtemplate($nrtemplate);
        $processo->setNrtipoprocesso($nrtipoprocesso);
        $processo->setNrparcnegociosolicita($nrparcnegociosolicita);
        $processo->setNrparcnegocioresp($nrparcnegocioresp);
        $processo->setDsmotivo($dsmotivo);
        $processo->setDsdescricao($dsdescricao);
        $processo->setDslocalidade($dslocalidade);        
        $processo->setDtsuspensao($dtsuspensao);
        $processo->setDtcancelamento($dtcancelamento);
        $processo->setDtretorno($dtretorno);
        $processo->setNrprioridade($nrprioridade);
        $processo->setDtconclusao($dtconclusao);
        $processo->setDtultatu(DateUtil::getDataAtual());
        $processo->setCdoperultatu($cdoperador);
        $processo->setNrorgultatu($nrorg);

        Utils::getEntityManager()->persist($processo);
        Utils::getEntityManager()->flush();
        Utils::getEntityManager()->commit();

        if ($update)
            return 'update';
        else
            return 'save';

    }
}